@@ -1,16 +1,20 @@
 import os
+import shutil
 import sys
 from pathlib import Path
 from typing import Any, Tuple, Union
 
 import arrow
 import click
+import inquirer
 import rich
-from lightning_cloud.openapi import Externalv1LightningappInstance
+from lightning_cloud.openapi import Externalv1LightningappInstance, V1LightningappInstanceState
+from lightning_cloud.openapi.rest import ApiException
 from requests.exceptions import ConnectionError
 
 from lightning.app import __version__ as ver
 from lightning.app.cli import cmd_init, cmd_install, cmd_pl_init, cmd_react_ui_init
+from lightning.app.cli.cmd_apps import _AppManager
 from lightning.app.cli.cmd_clusters import AWSClusterManager
 from lightning.app.cli.commands.app_commands import _run_app_command
 from lightning.app.cli.commands.connection import (
@@ -25,11 +29,17 @@ from lightning.app.cli.lightning_cli_create import create
 from lightning.app.cli.lightning_cli_delete import delete
 from lightning.app.cli.lightning_cli_list import get_list
 from lightning.app.cli.lightning_cli_remove import cli_remove
-from lightning.app.core.constants import DEBUG, get_lightning_cloud_url
+from lightning.app.core.constants import DEBUG, ENABLE_APP_COMMENT_COMMAND_EXECUTION, get_lightning_cloud_url
 from lightning.app.runners.runtime import dispatch
 from lightning.app.runners.runtime_type import RuntimeType
+from lightning.app.utilities.app_commands import run_app_commands
 from lightning.app.utilities.app_helpers import Logger
-from lightning.app.utilities.cli_helpers import _arrow_time_callback, _format_input_env_variables
+from lightning.app.utilities.cli_helpers import (
+    _arrow_time_callback,
+    _check_environment_and_redirect,
+    _check_version_and_upgrade,
+    _format_input_env_variables,
+)
 from lightning.app.utilities.cluster_logs import _cluster_logs_reader
 from lightning.app.utilities.exceptions import _ApiExceptionHandler, LogLinesLimitExceeded
 from lightning.app.utilities.login import Auth
@@ -49,6 +59,14 @@ def get_app_url(runtime_type: RuntimeType, *args: Any, need_credits: bool = Fals
 
 
 def main() -> None:
+    # Check environment and versions if not in the cloud
+    if "LIGHTNING_APP_STATE_URL" not in os.environ:
+        # Enforce running in PATH Python
+        _check_environment_and_redirect()
+
+        # Check for newer versions and upgrade
+        _check_version_and_upgrade()
+
     # 1: Handle connection to a Lightning App.
     if len(sys.argv) > 1 and sys.argv[1] in ("connect", "disconnect", "logout"):
         _main()
@@ -222,6 +240,7 @@ def _run_app(
     open_ui: bool,
     env: tuple,
     secret: tuple,
+    run_app_comment_commands: bool,
 ) -> None:
     file = _prepare_file(file)
 
@@ -242,6 +261,9 @@ def _run_app(
                 "Secrets can only be used for apps running in cloud. "
                 "Using the option --secret in local execution is not supported."
             )
+        if ENABLE_APP_COMMENT_COMMAND_EXECUTION or run_app_comment_commands:
+            if file is not None:
+                run_app_commands(str(file))
 
     env_vars = _format_input_env_variables(env)
     os.environ.update(env_vars)
@@ -268,6 +290,7 @@ def _run_app(
         env_vars=env_vars,
         secrets=secrets,
         cluster_id=cluster_id,
+        run_app_comment_commands=run_app_comment_commands,
     )
     if runtime_type == RuntimeType.CLOUD:
         click.echo("Application is ready in the cloud")
@@ -305,6 +328,14 @@ def run() -> None:
 @click.option("--env", type=str, default=[], multiple=True, help="Environment variables to be set for the app.")
 @click.option("--secret", type=str, default=[], multiple=True, help="Secret variables to be set for the app.")
 @click.option("--app_args", type=str, default=[], multiple=True, help="Collection of arguments for the app.")
+@click.option(
+    "--setup",
+    "-s",
+    "run_app_comment_commands",
+    is_flag=True,
+    default=False,
+    help="run environment setup commands from the app comments.",
+)
 def run_app(
     file: str,
     cloud: bool,
@@ -317,9 +348,22 @@ def run_app(
     env: tuple,
     secret: tuple,
     app_args: tuple,
+    run_app_comment_commands: bool,
 ) -> None:
     """Run an app from a file."""
-    _run_app(file, cloud, cluster_id, without_server, no_cache, name, blocking, open_ui, env, secret)
+    _run_app(
+        file,
+        cloud,
+        cluster_id,
+        without_server,
+        no_cache,
+        name,
+        blocking,
+        open_ui,
+        env,
+        secret,
+        run_app_comment_commands,
+    )
 
 
 @_main.group(hidden=True)
@@ -341,6 +385,87 @@ _main.add_command(cli_add)
 _main.add_command(cli_remove)
 
 
+@_main.command("ssh")
+@click.option(
+    "--app-name",
+    "app_name",
+    type=str,
+    default=None,
+    required=False,
+)
+@click.option(
+    "--component-name",
+    "component_name",
+    type=str,
+    default=None,
+    help="Specify which component to SSH into",
+)
+def ssh(app_name: str = None, component_name: str = None) -> None:
+    """SSH into a Lightning App."""
+
+    app_manager = _AppManager()
+    apps = app_manager.list_apps(phase_in=[V1LightningappInstanceState.RUNNING])
+    if len(apps) == 0:
+        raise click.ClickException("No running apps available. Start a Lightning App in the cloud to use this feature.")
+
+    available_app_names = [app.name for app in apps]
+    if app_name is None:
+        available_apps = [
+            inquirer.List(
+                "app_name",
+                message="What app to SSH into?",
+                choices=available_app_names,
+            ),
+        ]
+        app_name = inquirer.prompt(available_apps)["app_name"]
+    app_id = next((app.id for app in apps if app.name == app_name), None)
+    if app_id is None:
+        raise click.ClickException(
+            f"Unable to find a running app with name {app_name} in your account. "
+            + f"Available running apps are: {', '.join(available_app_names)}"
+        )
+    try:
+        instance = app_manager.get_app(app_id=app_id)
+    except ApiException:
+        raise click.ClickException("failed fetching app instance")
+
+    components = app_manager.list_components(app_id=app_id)
+    available_component_names = [work.name for work in components] + ["flow"]
+    if component_name is None:
+        available_components = [
+            inquirer.List(
+                "component_name",
+                message="Which component to SSH into?",
+                choices=available_component_names,
+            )
+        ]
+        component_name = inquirer.prompt(available_components)["component_name"]
+
+    component_id = None
+    if component_name == "flow":
+        component_id = f"lightningapp-{app_id}"
+    elif component_name is not None:
+        work_id = next((work.id for work in components if work.name == component_name), None)
+        if work_id is not None:
+            component_id = f"lightningwork-{work_id}"
+
+    if component_id is None:
+        raise click.ClickException(
+            f"Unable to find an app component with name {component_name}. "
+            f"Available components are: {', '.join(available_component_names)}"
+        )
+
+    app_cluster = app_manager.get_cluster(cluster_id=instance.spec.cluster_id)
+    ssh_endpoint = app_cluster.status.ssh_gateway_endpoint
+
+    ssh_path = shutil.which("ssh")
+    if ssh_path is None:
+        raise click.ClickException(
+            "Unable to find the ssh binary. You must install ssh first to use this functionality."
+        )
+    os.execv(ssh_path, ["-tt", f"{component_id}@{ssh_endpoint}"])
+
+
 @_main.group()
 def install() -> None:
     """Install a Lightning App and/or component."""
