@@ -1,11 +1,18 @@
 from lightning.app.components.database.client import DatabaseClient
 from lightning.app.components.database.server import Database
+from lightning.app.components.multi_node import (
+    LightningTrainerMultiNode,
+    LiteMultiNode,
+    MultiNode,
+    PyTorchSpawnMultiNode,
+)
 from lightning.app.components.python.popen import PopenPythonScript
 from lightning.app.components.python.tracer import Code, TracerPythonScript
 from lightning.app.components.serve.gradio import ServeGradio
+from lightning.app.components.serve.python_server import Image, Number, PythonServer
 from lightning.app.components.serve.serve import ModelInferenceAPI
 from lightning.app.components.serve.streamlit import ServeStreamlit
-from lightning.app.components.training import LightningTrainingComponent, PyTorchLightningScriptRunner
+from lightning.app.components.training import LightningTrainerScript, PyTorchLightningScriptRunner
 
 __all__ = [
     "DatabaseClient",
@@ -16,6 +23,13 @@ __all__ = [
     "ServeGradio",
     "ServeStreamlit",
     "ModelInferenceAPI",
-    "LightningTrainingComponent",
+    "PythonServer",
+    "Image",
+    "Number",
+    "MultiNode",
+    "LiteMultiNode",
+    "LightningTrainerScript",
     "PyTorchLightningScriptRunner",
+    "PyTorchSpawnMultiNode",
+    "LightningTrainerMultiNode",
 ]
