@@ -45,6 +45,7 @@ ORCHESTRATOR_COPY_REQUEST_CONSTANT = "ORCHESTRATOR_COPY_REQUEST"
 ORCHESTRATOR_COPY_RESPONSE_CONSTANT = "ORCHESTRATOR_COPY_RESPONSE"
 WORK_QUEUE_CONSTANT = "WORK_QUEUE"
 API_RESPONSE_QUEUE_CONSTANT = "API_RESPONSE_QUEUE"
+FLOW_TO_WORKS_DELTA_QUEUE_CONSTANT = "FLOW_TO_WORKS_DELTA_QUEUE"
 
 
 class QueuingSystem(Enum):
@@ -136,6 +137,14 @@ class QueuingSystem(Enum):
         )
         return self.get_queue(queue_name)
 
+    def get_flow_to_work_delta_queue(self, work_name: str, queue_id: Optional[str] = None) -> "BaseQueue":
+        queue_name = (
+            f"{queue_id}_{FLOW_TO_WORKS_DELTA_QUEUE_CONSTANT}_{work_name}"
+            if queue_id
+            else f"{FLOW_TO_WORKS_DELTA_QUEUE_CONSTANT}_{work_name}"
+        )
+        return self.get_queue(queue_name)
+
 
 class BaseQueue(ABC):
     """Base Queue class that has a similar API to the Queue class in python."""
@@ -234,6 +243,18 @@ class RedisQueue(BaseQueue):
         self.redis = redis.Redis(host=host, port=port, password=password)
 
     def put(self, item: Any) -> None:
+        from lightning.app import LightningWork
+
+        is_work = isinstance(item, LightningWork)
+
+        # TODO: Be careful to handle with a lock if another thread needs
+        # to access the work backend one day.
+        # The backend isn't picklable
+        # Raises a TypeError: cannot pickle '_thread.RLock' object
+        if is_work:
+            backend = item._backend
+            item._backend = None
+
         value = pickle.dumps(item)
         queue_len = self.length()
         if queue_len >= WARNING_QUEUE_SIZE:
@@ -252,6 +273,10 @@ class RedisQueue(BaseQueue):
                 "If the issue persists, please contact support@lightning.ai"
             )
 
+        # The backend isn't pickable.
+        if is_work:
+            item._backend = backend
+
     def get(self, timeout: int = None):
         """Returns the left most element of the redis queue.
 
